@@ -117,16 +117,16 @@ class MultiQubitSystem:
         POVM_list = ['h', 'v', 'd', 'a', 'r', 'l']
         repeated = np.repeat(POVM_list, 1000000)
         np.random.shuffle(repeated)
-        repeated_shuffled = repeated.reshape(-1, self.qubit_size)
-        sorted_proj = np.unique(repeated_shuffled, axis=0).reshape(-1,self.qubit_size)
+        repeated_shuffled = repeated.reshape(-1, self._qs)
+        sorted_proj = np.unique(repeated_shuffled, axis=0).reshape(-1,self._qs)
 
-        assert len(sorted_proj) == 6 ** self.qubit_size, 'Increase the sampling in the repeated povm list'
+        assert len(sorted_proj) == 6 ** self._qs, 'Increase the sampling in the repeated povm list'
         return sorted_proj
 
     def Alphabetical_Projectors(self):
         sorted_proj = self.Sorted_Proj_Strings()
         Proj = list(map(self.Kron_Povm, sorted_proj))
-        Proj = np.array(Proj).reshape(-1, 2 ** self.qubit_size, 2 ** self.qubit_size)
+        Proj = np.array(Proj).reshape(-1, 2 ** self._qs, 2 ** self._qs)
         return Proj
 
     def NISQ_Projectors(self):
